pub struct WorldBorderWarnTime(pub i32);Tuple Fields
0: i32Trait Implementations
Sourceimpl Clone for WorldBorderWarnTime
impl Clone for WorldBorderWarnTime
Sourcefn clone(&self) -> WorldBorderWarnTime
fn clone(&self) -> WorldBorderWarnTime
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Component for WorldBorderWarnTime
impl Component for WorldBorderWarnTime
Sourceconst STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
const STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
A constant indicating the storage type used for this component.
Sourcetype Mutability = Mutable
type Mutability = Mutable
A marker type to assist Bevy with determining if this component is
mutable, or immutable. Mutable components will have [
Component<Mutability = Mutable>],
while immutable components will instead have [Component<Mutability = Immutable>]. Read moreSourcefn register_required_components(
_requiree: ComponentId,
required_components: &mut RequiredComponentsRegistrator<'_, '_>,
)
fn register_required_components( _requiree: ComponentId, required_components: &mut RequiredComponentsRegistrator<'_, '_>, )
Registers required components. Read more
Sourcefn clone_behavior() -> ComponentCloneBehavior
fn clone_behavior() -> ComponentCloneBehavior
Called when registering this component, allowing to override clone function (or disable cloning altogether) for this component. Read more
Sourcefn relationship_accessor() -> Option<ComponentRelationshipAccessor<Self>>
fn relationship_accessor() -> Option<ComponentRelationshipAccessor<Self>>
Returns [
ComponentRelationshipAccessor] required for working with relationships in dynamic contexts. Read morefn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Gets the
on_add [ComponentHook] for this [Component] if one is defined.fn on_insert() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_insert() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Gets the
on_insert [ComponentHook] for this [Component] if one is defined.fn on_discard() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_discard() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Gets the
on_discard [ComponentHook] for this [Component] if one is defined.fn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Gets the
on_remove [ComponentHook] for this [Component] if one is defined.fn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Gets the
on_despawn [ComponentHook] for this [Component] if one is defined.fn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
fn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
Maps the entities on this component using the given [
EntityMapper]. This is used to remap entities in contexts like scenes and entity cloning.
When deriving [Component], this is populated by annotating fields containing entities with #[entities] Read moreSourceimpl Debug for WorldBorderWarnTime
impl Debug for WorldBorderWarnTime
Sourceimpl Default for WorldBorderWarnTime
impl Default for WorldBorderWarnTime
Sourceimpl Deref for WorldBorderWarnTime
impl Deref for WorldBorderWarnTime
Sourceimpl DerefMut for WorldBorderWarnTime
impl DerefMut for WorldBorderWarnTime
Sourceimpl Ord for WorldBorderWarnTime
impl Ord for WorldBorderWarnTime
Sourcefn cmp(&self, other: &WorldBorderWarnTime) -> Ordering
fn cmp(&self, other: &WorldBorderWarnTime) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WorldBorderWarnTime
impl PartialEq for WorldBorderWarnTime
Sourcefn eq(&self, other: &WorldBorderWarnTime) -> bool
fn eq(&self, other: &WorldBorderWarnTime) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WorldBorderWarnTime
impl PartialOrd for WorldBorderWarnTime
impl Copy for WorldBorderWarnTime
impl Eq for WorldBorderWarnTime
impl StructuralPartialEq for WorldBorderWarnTime